@@ -14,7 +14,7 @@ pub struct GidReal {
 impl GidReal {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("RGID"));
-        let unit = String::from("");
+        let unit = String::new();
         GidReal {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -25,14 +25,14 @@ impl GidReal {
     }
 }
 
-#[cfg(target_os = "linux")]
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for GidReal {
     fn add(&mut self, proc: &ProcessInfo) {
         let (fmt_content, raw_content) = if let Some(ref status) = proc.curr_status {
             let gid = status.rgid;
-            (format!("{}", gid), gid)
+            (format!("{gid}"), gid)
         } else {
-            (String::from(""), 0)
+            (String::new(), 0)
         };
 
         self.fmt_contents.insert(proc.pid, fmt_content);
