@@ -18,7 +18,7 @@ pub struct Group {
 impl Group {
     pub fn new(header: Option<String>, abbr_sid: bool) -> Self {
         let header = header.unwrap_or_else(|| String::from("Group"));
-        let unit = String::from("");
+        let unit = String::new();
         Group {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -35,13 +35,13 @@ impl Column for Group {
     fn add(&mut self, proc: &ProcessInfo) {
         let fmt_content = if let Some(ref status) = proc.curr_status {
             let gid = status.egid;
-            if let Some(group) = users::get_group_by_gid(gid as u32) {
+            if let Some(group) = users::get_group_by_gid(gid) {
                 format!("{}", group.name().to_string_lossy())
             } else {
-                format!("{}", gid)
+                format!("{gid}")
             }
         } else {
-            String::from("")
+            String::new()
         };
         let raw_content = fmt_content.clone();
 
@@ -79,7 +79,7 @@ impl Column for Group {
         let mut kind = std::u64::MAX;
         for g in &proc.groups {
             if g.sid.len() > 3 && g.sid[1] == 5 && g.sid[2] == 32 && kind > g.sid[3] {
-                sid_name = &g;
+                sid_name = g;
                 kind = g.sid[3];
             }
         }
