@@ -6,7 +6,9 @@ pub mod docker;
 pub mod eip;
 pub mod elapsed_time;
 pub mod empty;
+pub mod env;
 pub mod esp;
+pub mod file_name;
 pub mod gid;
 pub mod gid_fs;
 pub mod gid_real;
@@ -27,6 +29,7 @@ pub mod priority;
 pub mod processor;
 pub mod read_bytes;
 pub mod rt_priority;
+pub mod sec_context;
 pub mod separator;
 pub mod session;
 pub mod shd_pnd;
@@ -69,6 +72,7 @@ pub mod vm_size;
 pub mod vm_stack;
 pub mod vm_swap;
 pub mod wchan;
+pub mod work_dir;
 pub mod write_bytes;
 
 pub use self::command::Command;
@@ -79,7 +83,9 @@ pub use self::docker::Docker;
 pub use self::eip::Eip;
 pub use self::elapsed_time::ElapsedTime;
 pub use self::empty::Empty;
+pub use self::env::Env;
 pub use self::esp::Esp;
+pub use self::file_name::FileName;
 pub use self::gid::Gid;
 pub use self::gid_fs::GidFs;
 pub use self::gid_real::GidReal;
@@ -100,6 +106,7 @@ pub use self::priority::Priority;
 pub use self::processor::Processor;
 pub use self::read_bytes::ReadBytes;
 pub use self::rt_priority::RtPriority;
+pub use self::sec_context::SecContext;
 pub use self::separator::Separator;
 pub use self::session::Session;
 pub use self::shd_pnd::ShdPnd;
@@ -142,6 +149,7 @@ pub use self::vm_size::VmSize;
 pub use self::vm_stack::VmStack;
 pub use self::vm_swap::VmSwap;
 pub use self::wchan::Wchan;
+pub use self::work_dir::WorkDir;
 pub use self::write_bytes::WriteBytes;
 
 use crate::column::Column;
@@ -162,7 +170,9 @@ pub enum ConfigColumnKind {
     Eip,
     ElapsedTime,
     Empty,
+    Env,
     Esp,
+    FileName,
     Gid,
     GidFs,
     GidReal,
@@ -183,6 +193,7 @@ pub enum ConfigColumnKind {
     Processor,
     ReadBytes,
     RtPriority,
+    SecContext,
     Separator,
     Session,
     ShdPnd,
@@ -226,6 +237,7 @@ pub enum ConfigColumnKind {
     VmStack,
     VmSwap,
     Wchan,
+    WorkDir,
     WriteBytes,
 }
 
@@ -252,7 +264,9 @@ pub fn gen_column(
         ConfigColumnKind::Eip => Box::new(Eip::new(header)),
         ConfigColumnKind::ElapsedTime => Box::new(ElapsedTime::new(header)),
         ConfigColumnKind::Empty => Box::new(Empty::new()),
+        ConfigColumnKind::Env => Box::new(Env::new(header)),
         ConfigColumnKind::Esp => Box::new(Esp::new(header)),
+        ConfigColumnKind::FileName => Box::new(FileName::new(header)),
         ConfigColumnKind::Gid => Box::new(Gid::new(header, abbr_sid)),
         ConfigColumnKind::GidFs => Box::new(GidFs::new(header)),
         ConfigColumnKind::GidReal => Box::new(GidReal::new(header)),
@@ -273,6 +287,7 @@ pub fn gen_column(
         ConfigColumnKind::Processor => Box::new(Processor::new(header)),
         ConfigColumnKind::ReadBytes => Box::new(ReadBytes::new(header)),
         ConfigColumnKind::RtPriority => Box::new(RtPriority::new(header)),
+        ConfigColumnKind::SecContext => Box::new(SecContext::new(header)),
         ConfigColumnKind::Separator => Box::new(Separator::new(separator)),
         ConfigColumnKind::Session => Box::new(Session::new(header)),
         ConfigColumnKind::ShdPnd => Box::new(ShdPnd::new(header)),
@@ -316,6 +331,7 @@ pub fn gen_column(
         ConfigColumnKind::VmStack => Box::new(VmStack::new(header)),
         ConfigColumnKind::VmSwap => Box::new(VmSwap::new(header)),
         ConfigColumnKind::Wchan => Box::new(Wchan::new(header)),
+        ConfigColumnKind::WorkDir => Box::new(WorkDir::new(header)),
         ConfigColumnKind::WriteBytes => Box::new(WriteBytes::new(header)),
     }
 }
@@ -349,7 +365,9 @@ pub static KIND_LIST: Lazy<HashMap<ConfigColumnKind, (&'static str, &'static str
                 ("ElapsedTime", "Elapsed time"),
             ),
             (ConfigColumnKind::Empty, ("Empty", "Empty")),
+            (ConfigColumnKind::Env, ("Env", "Environment variables")),
             (ConfigColumnKind::Esp, ("Esp", "Stack pointer")),
+            (ConfigColumnKind::FileName, ("FileName", "File name")),
             (ConfigColumnKind::Gid, ("Gid", "Group ID")),
             (ConfigColumnKind::GidFs, ("GidFs", "File system group ID")),
             (ConfigColumnKind::GidReal, ("GidReal", "Real group ID")),
@@ -397,6 +415,10 @@ pub static KIND_LIST: Lazy<HashMap<ConfigColumnKind, (&'static str, &'static str
                 ConfigColumnKind::RtPriority,
                 ("RtPriority", "Real-time priority"),
             ),
+            (
+                ConfigColumnKind::SecContext,
+                ("SecContext", "Security context"),
+            ),
             (
                 ConfigColumnKind::Separator,
                 ("Separator", "Show | for column separation"),
@@ -480,6 +502,10 @@ pub static KIND_LIST: Lazy<HashMap<ConfigColumnKind, (&'static str, &'static str
                 ConfigColumnKind::Wchan,
                 ("Wchan", "Process sleeping kernel function"),
             ),
+            (
+                ConfigColumnKind::WorkDir,
+                ("WorkDir", "Current working directory"),
+            ),
             (
                 ConfigColumnKind::WriteBytes,
                 ("WriteBytes", "Write bytes to storage"),
@@ -550,6 +576,141 @@ numeric_search = false
 nonnumeric_search = true
 "#;
 
+// ---------------------------------------------------------------------------------------------------------------------
+// CONFIG_LARGE
+// ---------------------------------------------------------------------------------------------------------------------
+
+pub static CONFIG_LARGE: &str = r#"
+[[columns]]
+kind = "Pid"
+style = "BrightYellow|Yellow"
+numeric_search = true
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "User"
+style = "BrightGreen|Green"
+numeric_search = false
+nonnumeric_search = true
+align = "Left"
+[[columns]]
+kind = "Separator"
+style = "White|BrightBlack"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "State"
+style = "ByState"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "Nice"
+style = "BrightMagenta|Magenta"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "Tty"
+style = "BrightWhite|Black"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "UsageCpu"
+style = "ByPercentage"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "UsageMem"
+style = "ByPercentage"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "VmSize"
+style = "ByUnit"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "VmRss"
+style = "ByUnit"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "TcpPort"
+style = "BrightCyan|Cyan"
+numeric_search = true
+nonnumeric_search = false
+align = "Left"
+max_width = 20
+[[columns]]
+kind = "UdpPort"
+style = "BrightCyan|Cyan"
+numeric_search = true
+nonnumeric_search = false
+align = "Left"
+max_width = 20
+[[columns]]
+kind = "ReadBytes"
+style = "ByUnit"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "WriteBytes"
+style = "ByUnit"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "Slot"
+style = "ByUnit"
+numeric_search = false
+nonnumeric_search = false
+align = "Right"
+[[columns]]
+kind = "Separator"
+style = "White|BrightBlack"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "CpuTime"
+style = "BrightCyan|Cyan"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "StartTime"
+style = "BrightMagenta|Magenta"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "Docker"
+style = "BrightGreen|Green"
+numeric_search = false
+nonnumeric_search = true
+align = "Left"
+[[columns]]
+kind = "Separator"
+style = "White|BrightBlack"
+numeric_search = false
+nonnumeric_search = false
+align = "Left"
+[[columns]]
+kind = "Command"
+style = "BrightWhite|Black"
+numeric_search = false
+nonnumeric_search = true
+align = "Left"
+"#;
+
 // ---------------------------------------------------------------------------------------------------------------------
 // CONFIG_ALL
 // ---------------------------------------------------------------------------------------------------------------------
@@ -581,9 +742,15 @@ style = "BrightYellow"
 kind = "Empty"
 style = "BrightYellow"
 [[columns]]
+kind = "Env"
+style = "BrightYellow"
+[[columns]]
 kind = "Esp"
 style = "BrightBlue"
 [[columns]]
+kind = "FileName"
+style = "BrightBlue"
+[[columns]]
 kind = "Gid"
 style = "White"
 [[columns]]
@@ -644,6 +811,9 @@ style = "Cyan"
 kind = "RtPriority"
 style = "White"
 [[columns]]
+kind = "SecContext"
+style = "White"
+[[columns]]
 kind = "Separator"
 style = "White"
 [[columns]]
@@ -764,6 +934,9 @@ style = "ByUnit"
 kind = "Wchan"
 style = "White"
 [[columns]]
+kind = "WorkDir"
+style = "White"
+[[columns]]
 kind = "WriteBytes"
 style = "White"
 "#;
