@@ -15,13 +15,14 @@ use crate::util::{adjust, get_theme, lap, ArgColorMode, ArgPagerMode, ArgThemeMo
 use crate::view::View;
 use crate::watcher::Watcher;
 use anyhow::{anyhow, Context, Error};
-use clap::{IntoApp, Parser};
+use clap::{ArgEnum, IntoApp, Parser};
 use clap_complete::Shell;
 use console::Term;
 use std::cmp;
 use std::collections::HashMap;
 use std::fs;
 use std::io::{stdout, Read};
+use std::path::PathBuf;
 use std::time::Instant;
 use unicode_width::UnicodeWidthStr;
 
@@ -29,6 +30,12 @@ use unicode_width::UnicodeWidthStr;
 // Opt
 // ---------------------------------------------------------------------------------------------------------------------
 
+#[derive(Clone, Debug, ArgEnum)]
+pub enum BuiltinConfig {
+    Default,
+    Large,
+}
+
 #[derive(Debug, Parser)]
 #[clap(long_version(option_env!("LONG_VERSION").unwrap_or(env!("CARGO_PKG_VERSION"))))]
 #[clap(setting(clap::AppSettings::DeriveDisplayOrder))]
@@ -152,17 +159,25 @@ pub struct Opt {
     )]
     pub interval: u64,
 
+    /// Use built-in configuration
+    #[clap(action, long = "use-config", value_name = "name")]
+    pub use_config: Option<BuiltinConfig>,
+
+    /// Load configuration from file
+    #[clap(action, long = "load-config", value_name = "path")]
+    pub load_config: Option<PathBuf>,
+
     /// Generate configuration sample file
-    #[clap(action, long = "config")]
-    pub config: bool,
+    #[clap(action, long = "gen-config")]
+    pub gen_config: bool,
 
     /// Generate shell completion file
-    #[clap(action, long = "completion", value_name = "shell")]
-    pub completion: Option<Shell>,
+    #[clap(action, long = "gen-completion", value_name = "shell")]
+    pub gen_completion: Option<Shell>,
 
     /// Generate shell completion file and write to stdout
-    #[clap(action, long = "completion-out", value_name = "shell")]
-    pub completion_out: Option<Shell>,
+    #[clap(action, long = "gen-completion-out", value_name = "shell")]
+    pub gen_completion_out: Option<Shell>,
 
     /// Suppress header
     #[clap(action, long = "no-header")]
@@ -178,7 +193,7 @@ pub struct Opt {
 // ---------------------------------------------------------------------------------------------------------------------
 
 #[cfg_attr(tarpaulin, skip)]
-fn get_config() -> Result<Config, Error> {
+fn get_config(opt: &Opt) -> Result<Config, Error> {
     let dot_cfg_path = directories::BaseDirs::new()
         .map(|base| base.home_dir().join(".procs.toml"))
         .filter(|path| path.exists());
@@ -193,7 +208,12 @@ fn get_config() -> Result<Config, Error> {
                 .join("config.toml")
         })
         .filter(|path| path.exists());
-    let cfg_path = dot_cfg_path.or(app_cfg_path).or(xdg_cfg_path);
+    let cfg_path = opt
+        .load_config
+        .clone()
+        .or(dot_cfg_path)
+        .or(app_cfg_path)
+        .or(xdg_cfg_path);
 
     let config: Config = if let Some(path) = cfg_path {
         let mut f = fs::File::open(&path).context(format!("failed to open file ({path:?})"))?;
@@ -206,7 +226,11 @@ fn get_config() -> Result<Config, Error> {
         toml::from_str(CONFIG_DEFAULT).unwrap()
     };
 
-    Ok(config)
+    match opt.use_config {
+        Some(BuiltinConfig::Default) => Ok(toml::from_str(CONFIG_DEFAULT).unwrap()),
+        Some(BuiltinConfig::Large) => Ok(toml::from_str(CONFIG_LARGE).unwrap()),
+        None => Ok(config),
+    }
 }
 
 fn check_old_config(s: &str, config: Result<Config, toml::de::Error>) -> Result<Config, Error> {
@@ -253,11 +277,11 @@ fn run() -> Result<(), Error> {
     let mut opt: Opt = Parser::parse();
     opt.watch_mode = opt.watch || opt.watch_interval.is_some();
 
-    if opt.config {
-        run_config()
+    if opt.gen_config {
+        run_gen_config()
     } else if opt.list {
         run_list()
-    } else if let Some(shell) = opt.completion {
+    } else if let Some(shell) = opt.gen_completion {
         //Opt::clap().gen_completions("procs", shell, "./");
         clap_complete::generate_to(shell, &mut Opt::command(), "procs", "./")?;
         let path = match shell {
@@ -270,12 +294,12 @@ fn run() -> Result<(), Error> {
         };
         println!("completion file is generated: {path}");
         Ok(())
-    } else if let Some(shell) = opt.completion_out {
+    } else if let Some(shell) = opt.gen_completion_out {
         //Opt::clap().gen_completions_to("procs", shell, &mut stdout());
         clap_complete::generate(shell, &mut Opt::command(), "procs", &mut stdout());
         Ok(())
     } else {
-        let config = get_config()?;
+        let config = get_config(&opt)?;
         if opt.watch_mode {
             let interval = match opt.watch_interval {
                 Some(n) => (n * 1000.0).round() as u64,
@@ -288,7 +312,7 @@ fn run() -> Result<(), Error> {
     }
 }
 
-fn run_config() -> Result<(), Error> {
+fn run_gen_config() -> Result<(), Error> {
     let config: Config = toml::from_str(CONFIG_DEFAULT).unwrap();
     let toml = toml::to_string(&config)?;
     println!("{toml}");
@@ -417,8 +441,8 @@ mod tests {
     }
 
     #[test]
-    fn test_run_config() {
-        let ret = run_config();
+    fn test_run_gen_config() {
+        let ret = run_gen_config();
         assert!(ret.is_ok());
     }
 
@@ -496,4 +520,16 @@ mod tests {
         let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
+
+    #[test]
+    fn test_run_use_config() {
+        let mut config: Config = toml::from_str(CONFIG_DEFAULT).unwrap();
+        config.pager.mode = ConfigPagerMode::Disable;
+        config.display.theme = ConfigTheme::Dark;
+
+        let args = vec!["procs", "--use-config", "large"];
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
+        assert!(ret.is_ok());
+    }
 }
